// Translated by: Gabucino the Almighty! <gabucino@mplayerhq.hu>
// Send me money/hw/babes!
// ... Okay enough of the hw, now send the other two!

// In synch with rev 1.95

// ========================= MPlayer help ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char help_text[]=
"Indts:   mplayer [opcik] [url|tvonal/]filenv\n"
"\n"
"Alapvet opcik: (az sszes opci listjhoz lsd a man lapot!)\n"
" -vo <drv[:dev]> videomeghajt s -alegysg kivlasztsa (lista: '-vo help')\n"
" -ao <drv[:dev]> audiomeghajt s -alegysg kivlasztsa (lista: '-ao help')\n"
#ifdef HAVE_VCD
" -vcd <svszm>  lejtszs VCD (video cd)-svbl, kzvetlenl az eszkzrl\n"
#endif
#ifdef HAVE_LIBCSS
" -dvdauth <megh> DVD-meghajt elrsi tjnak megadsa (kdolt lemezekhez)\n"
#endif
#ifdef USE_DVDREAD
" -dvd <titleno>  a megadott DVD sv lejtszsa, file helyett\n"
" -alang/-slang   DVD audio/felirat nyelv kivlasztsa (2 bets orszgkddal)\n"
#endif
" -ss <idpoz>    a megadott (msodperc v. ra:perc:mperc) pozcira tekers\n"
" -nosound        hanglejtszs kikapcsolsa\n"
" -fs -vm -zoom   teljeskpernys lejtszs opcii (teljkp,mdvlt,szoft.nagy)\n"
" -x <x> -y <y>   lejtszsi ablak felbontsnak fellbrlata (mdvltshoz vagy szoftveres nagytshoz)\n"
" -sub <file>     felhasznland felirat-file megadsa (lsd -subfps, -subdelay)\n"
" -playlist <file> lejtszsi lista file megadsa\n"
" -vid x -aid y   lejtszand video- (x) s audio- (y) stream-ek kivlasztsa\n"
" -fps x -srate y video (x kpkocka/mp) s audio (y Hz) rta megadsa\n"
" -pp <minsg>   kpjavts fokozatainak belltsa (lsd a man lapot)\n"
" -framedrop      kpkockk eldobsnak engedlyezse (lass gpekhez)\n"
"\n"
"Legfontosabb billentyk: (a teljes listhoz lsd a man lapot, s az input.conf file-t)\n"
" <-  vagy  ->    10 msodperces htra/elre ugrs\n"
" fel vagy le     1 percnyi htra/elre ugrs\n"
" pgup v. pgdown  10 percnyi htra/elre ugrs\n"
" < vagy >        1 file-al elre/htra lps a lejtszsi listban\n"
" p vagy SPACE    pillanatllj (brmely billentyre tovbbmegy)\n"
" q vagy ESC      kilps\n"
" + vagy -        audio ksleltetse +/- 0.1 msodperccel\n"
" o               OSD-md vltsa:  nincs / keressv / keressv+id\n"
" * vagy /        hanger fel/le\n"
" z vagy x        felirat ksleltetse +/- 0.1 msodperccel\n"
" r vagy t        felirat pozcijnak megvltoztatsa, lsd -vop expand-ot is!\n"
"\n"
" * * * A MANPAGE TOVBBI RSZLETEKET, OPCIKAT, BILLENTYKET TARTALMAZ ! * * *\n"
"\n";
#endif

// ========================= MPlayer messages ===========================

// mplayer.c: 

#define MSGTR_Exiting "\nKilpek... (%s)\n"
#define MSGTR_Exit_quit "Kilps"
#define MSGTR_Exit_eof "Vge a file-nak"
#define MSGTR_Exit_error "Vgzetes hiba"
#define MSGTR_IntBySignal "\nAz MPlayer futsa %d-es szignl miatt megszakadt a %s modulban\n"
#define MSGTR_NoHomeDir "Nem tallom a HOME konyvtrat\n"
#define MSGTR_GetpathProblem "get_path(\"config\") problma\n"
#define MSGTR_CreatingCfgFile "Konfigurcis file ltrehozsa: %s\n"
#define MSGTR_InvalidVOdriver "Nem ltez video meghajt: %s\nHasznld a '-vo help' opcit, hogy listt kapj a hasznlhat vo meghajtkrl.\n"
#define MSGTR_InvalidAOdriver "Nem ltez audio meghajt: %s\nHasznld az '-ao help' opcit, hogy listt kapj a hasznlhat ao meghajtkrl.\n"
#define MSGTR_CopyCodecsConf "(msold/linkeld az etc/codecs.conf file-t ~/.mplayer/codecs.conf-ba)\n"
#define MSGTR_BuiltinCodecsConf "Befordtott codecs.conf - ot hasznlom.\n"
#define MSGTR_CantLoadFont "Nem tudom betlteni a kvetkez fontot: %s\n"
#define MSGTR_CantLoadSub "Nem tudom betlteni a feliratot: %s\n"
#define MSGTR_ErrorDVDkey "Hiba a DVD-KULCS feldolgozsa kzben.\n"
#define MSGTR_CmdlineDVDkey "A parancssorban megadott DVD-kulcs tovbbi dekdols cljbl eltrolsra kerlt.\n"
#define MSGTR_DVDauthOk "DVD-autentikcis folyamat, gy tnik, sikerrel vgzdtt.\n"
#define MSGTR_DumpSelectedStreamMissing "dump: VGZETES HIBA: a krt stream nem tallhat!\n"
#define MSGTR_CantOpenDumpfile "Nem tudom megnyitni a dump file-t!\n"
#define MSGTR_CoreDumped "Kinyomattam a cuccost, jl.\n"
#define MSGTR_FPSnotspecified "Az FPS (kpkocka/mp) rtk nincs megadva, vagy hibs! Hasznld az -fps opcit!\n"
#define MSGTR_TryForceAudioFmtStr "Megprblom a(z) %s audio codec-csaldot hasznlni ...\n"
#define MSGTR_CantFindAfmtFallback "A megadott audio codec-csaldban nem talltam ideval meghajtt, prblkozok ms meghajtval.\n"
#define MSGTR_CantFindAudioCodec "Nem tallok codecet a(z) 0x%X audio-formtumhoz !\n"
#define MSGTR_TryUpgradeCodecsConfOrRTFM "*** Frisstsd a %s-t az etc/codecs.conf-bl\n*** Ha mg mindig nem j, olvasd el a DOCS/codecs.html-t!\n"
#define MSGTR_CouldntInitAudioCodec "Nem tudom indtani az audio codecet! -> nincshang ;)\n"
#define MSGTR_TryForceVideoFmtStr "Megprblom a(z) %s video codec-csaldot hasznlni ...\n"
#define MSGTR_CantFindVideoCodec "Nem tallok codec-et ami megfelel a kivalasztott vo-hoz es 0x%X video-formtumhoz !\n"
#define MSGTR_VOincompCodec "A kivlasztott video_out meghajt inkompatibilis ezzel a codec-kel.\n"
#define MSGTR_CannotInitVO "VGZETES HIBA: Nem tudom elindtani a video-meghajtt!\n"
#define MSGTR_CannotInitAO "nem tudom megnyitni az audio-egysget -> NOSOUND\n"
#define MSGTR_StartPlaying "Lejtszs indtsa...\n"

#define MSGTR_SystemTooSlow "\n\n"\
"         ***************************************\n"\
"         **** A rendszered tl LASS ehhez! ****\n"\
"         ***************************************\n"\
"Lehetsges okok, s megoldsaik:\n"\
"- Legyakrabban : hibs _audio_ meghajt\n"\
"  - Prbld ki az -ao sdl opcit, vagy hasznld az ALSA 0.9 OSS emulcijt.\n"\
"  - Adj klnbz rtkeket az -autosync opcinak, kezdetnek a 30 megteszi.\n"\
"- Lass videokimenet\n"\
"  - Egy msik -vo meghajt kiprblsa eredmnyre vezethet (a listhoz lsd\n"\
"    -vo help), s/vagy hasznld a -framedrop opcit!\n"\
"- Lass CPU\n"\
"  - Nagy felbonts DivX/DVD lejtszsval nem rdemes gyenge processzoron\n"\
"    prblkozni! Esetleg -hardframedrop ?\n"\
"- Hibs file\n"\
"  - A -nobps -ni -forceidx -mc opcik kombincival rdemes szrakozni.\n"\
"- Lass mdia (NFS/SMB, DVD, VCD, stb)\n"\
"  - Prbld ki a -cache 8192 opcit.\n"\
"- Taln egy non-interleaved AVI filet prblsz -cache opcival lejtszani?\n"\
"  - Hasznld a -nocache opcit.\n"\
"Tuninghoz tippeket a DOCS/video.html s DOCS/sound.html file-ok tartalmaznak.\n"\
"Ha ezek utn sem tetszik az eredmny, olvasd el a DOCS/bugreports.html file-t.\n\n"

#define MSGTR_NoGui "Az MPlayer grafikus fellet NLKL lett fordtva!\n"
#define MSGTR_GuiNeedsX "Az MPlayer grafikus felletnek X11-re van szksge!\n"
#define MSGTR_Playing "%s lejtszsa\n"
#define MSGTR_NoSound "Audio: nincs hang!!!\n"
#define MSGTR_FPSforced "FPS knyszertve %5.3f  (ftime: %5.3f)\n"
#define MSGTR_CompiledWithRuntimeDetection "Futsidej CPU Detektls hasznlata - ez nem optimlis! A legjobb teljestmny elrshez fordtsd jra az MPlayer-t a --disable-runtime-cpudetection\n opcival\n"
#define MSGTR_CompiledWithCPUExtensions "x86-os CPU - a kvetkez kiterjesztsek hasznlata:"
#define MSGTR_AvailableVideoOutputPlugins "Rendelkezsre ll video pluginek:\n"
#define MSGTR_AvailableVideoOutputDrivers "Rendelkezsre ll video meghajtk:\n"
#define MSGTR_AvailableAudioOutputDrivers "Rendelkezsre ll audio meghajtk:\n"
#define MSGTR_AvailableAudioCodecs "Rendelkezsre ll audio codec-ek:\n"
#define MSGTR_AvailableVideoCodecs "Rendelkezsre ll video codec-ek:\n"
#define MSGTR_AvailableAudioFm "\nRendelkezsre ll (befordtott) audio codec csaldok/meghajtk:\n"
#define MSGTR_AvailableVideoFm "\nRendelkezsre ll (befordtott) video codec csaldok/meghajtk:\n"
#define MSGTR_AvailableFsType "A hasznlhat teljeskpernys rteg-mdok:\n"
#define MSGTR_UsingRTCTiming "Linux hardveres RTC idzts hasznlata (%ldHz)\n"
#define MSGTR_CannotReadVideoProperties "Video: tulajdonsgok beolvassa nem lehetsges\n"
#define MSGTR_NoStreamFound "Nem tallhat stream\n"
#define MSGTR_InitializingAudioCodec "Audio codec inicializlsa...\n"
#define MSGTR_ErrorInitializingVODevice "Hiba a kivlasztott video_out (-vo) egysg inicializsakor!\n"
#define MSGTR_ForcedVideoCodec "Knyszertett video codec: %s\n"
#define MSGTR_ForcedAudioCodec "Knyszertett audio codec: %s\n"
#define MSGTR_AODescription_AOAuthor "AO: Lers: %s\nAO: Kszt: %s\n"
#define MSGTR_AOComment "AO: Komment: %s\n"
#define MSGTR_Video_NoVideo "Video: nincs video!!!\n"
#define MSGTR_NotInitializeVOPorVO "\nHIBA: Nem sikerlt a video filterek (-vop) vagy a video kimenet (-vo) inicializlsa!\n"
#define MSGTR_Paused "\n  =====  SZNET  =====\r"
#define MSGTR_PlaylistLoadUnable "\nLejtszsi lista (%s) betltse sikertelen\n"
#define MSGTR_Exit_SIGILL_RTCpuSel \
"- Az MPlayer egy 'illeglis utastst' hajtott vgre.\n"\
"  Lehet hogy a futsidej CPU detektl kd bugja...\n"\
"  Olvasd el a DOCS/bugreports.html file-t.\n"
#define MSGTR_Exit_SIGILL \
"- Az MPlayer egy 'illeglis utastst' hajtott vgre.\n"\
"  Ez akkor trtnik amikor ms CPU-n futtatod az MPlayer-t mint amire a\n"\
"  fordts/optimalizls trtnt.\n  Ellenrizd!\n"
#define MSGTR_Exit_SIGSEGV_SIGFPE \
"- Az MPlayer rpke flrelpse miatt hiba lpett fel a CPU/FPU/RAM-ban.\n"\
"  Fordtsd jra az MPlayer-t az --enable-debug opcival, s kszts egy\n"\
"  'gdb' backtrace-t. A rszletek a DOCS/bugreports.html file-ban tallhatak.\n"
#define MSGTR_Exit_SIGCRASH \
"- Az MPlayer elcrashelt. Ennek nem lenne szabad megtrtnnie.\n"\
"  Az ok lehet egy hiba az MPlayer kdjban _vagy_ a Te meghajtidban, _vagy_\n"\
"  a gcc-ben. Ha gy vled hogy ez egy MPlayer hiba, gy olvasd el a\n"\
"  DOCS/bugreports.html file-t. Amig ezt figyelmesen meg nem teszed, nem tudunk\n"\
"  segteni.\n"


// mencoder.c:

#define MSGTR_UsingPass3ControllFile "Pass3 file hasznlata: %s\n"
#define MSGTR_MissingFilename "\nHinyz filenv!\n\n"
#define MSGTR_CannotOpenFile_Device "File/eszkz megnyitsa sikertelen\n"
#define MSGTR_ErrorDVDAuth "Hiba a DVD authentikci kzben...\n"
#define MSGTR_CannotOpenDemuxer "Demuxer meghvsa sikertelen\n"
#define MSGTR_NoAudioEncoderSelected "\nNem vlasztottl ki audio enkdert (-oac)! Vlassz egyet, vagy hasznld a -nosound opcit. Lsd -oac help!\n"
#define MSGTR_NoVideoEncoderSelected "\nNem vlasztottl ki video enkdert (-ovc)! Vlassz egyet, lsd -ovc help!\n"
#define MSGTR_InitializingAudioCodec "Audio codec inicializlsa...\n"
#define MSGTR_CannotOpenOutputFile "Nem tudom a kimeneti file-t (%s) megnyitni\n"
#define MSGTR_EncoderOpenFailed "Enkder meghvsa sikertelen\n"
#define MSGTR_ForcingOutputFourcc "Kimeneti fourcc knyszertse: %x [%.4s]\n"
#define MSGTR_WritingAVIHeader "AVI fejlc rsa...\n"
#define MSGTR_DuplicateFrames "\n%d darab kpkocka duplzsa!!!     \n"
#define MSGTR_SkipFrame "\nkpkocka tugrsa!!!     \n"
#define MSGTR_ErrorWritingFile "%s: hiba a file rsnl.\n"
#define MSGTR_WritingAVIIndex "\nAVI index rsa...\n"
#define MSGTR_FixupAVIHeader "AVI fejlc fixlsa...\n"
#define MSGTR_RecommendedVideoBitrate "Ajnlott video bitrta %s CD-hez: %d\n"
#define MSGTR_VideoStreamResult "\nVideo stream: %8.3f kbit/mp  (%d bps)  mret: %d byte  %5.3f mp  %d kpkocka\n"
#define MSGTR_AudioStreamResult "\nAudio stream: %8.3f kbit/mp  (%d bps)  mret: %d byte  %5.3f mp\n"

// cfg-mencoder.h:

#define MSGTR_MEncoderMP3LameHelp "\n\n"\
" vbr=<0-4>     a vltoz bitrtj enkdols mdja\n"\
"                0: cbr\n"\
"                1: mt\n"\
"                2: rh(alaprtelmezett)\n"\
"                3: abr\n"\
"                4: mtrh\n"\
"\n"\
" abr           tlagos bitrta\n"\
"\n"\
" cbr           konstans bitrta\n"\
"               Forces also CBR mode encoding on subsequent ABR presets modes\n"\
"\n"\
" br=<0-1024>   bitrta kBit-ben (csak CBR s ABR)\n"\
"\n"\
" q=<0-9>       minsg (0-legjobb, 9-legrosszabb) (csak VBR-nl)\n"\
"\n"\
" aq=<0-9>      algoritmikus minsg (0-legjobb, 9-legrosszabb/leggyorsabb)\n"\
"\n"\
" ratio=<1-100> tmrts arnya\n"\
"\n"\
" vol=<0-10>    audio bemenet hangereje\n"\
"\n"\
" mode=<0-3>    (alap: automatikus)\n"\
"                0: stereo\n"\
"                1: joint-stereo\n"\
"                2: dualchannel\n"\
"                3: mono\n"\
"\n"\
" padding=<0-2>\n"\
"                0: nincs\n"\
"                1: mind\n"\
"                2: llts\n"\
"\n"\
" fast          valamivel gyorsabb VBR enkdols, kicsit rosszabb minsg s\n"\
"               magasabb bitrta.\n"\
"\n"\
" preset=<rtk> elre belltott rtkek.\n"\
"                 medium: VBR  enkdols,  kellemes minsg\n"\
"                 (150-180 kbps bitrta tartomny)\n"\
"                 standard:  VBR enkdols, j minsg\n"\
"                 (170-210 kbps bitrta tartomny)\n"\
"                 extreme: VBR enkdols, nagyon j minsg\n"\
"                 (200-240 kbps bitrta tartomny)\n"\
"                 insane:  CBR  enkdols, legjobb minsg\n"\
"                 (320 kbps bitrta)\n"\
"                 <8-320>: ABR enkdols tlagban a megadott bitrtval.\n\n"

// open.c, stream.c:
#define MSGTR_CdDevNotfound "A CD-ROM meghajt (%s) nem tallhat!\n"
#define MSGTR_ErrTrackSelect "Hiba a VCD-sv kivlasztsakor!"
#define MSGTR_ReadSTDIN "Olvass a szabvnyos bemenetrl (stdin)...\n"
#define MSGTR_UnableOpenURL "Nem megnyithat az URL: %s\n"
#define MSGTR_ConnToServer "Csatlakozom a szerverhez: %s\n"
#define MSGTR_FileNotFound "A file nem tallhat: '%s'\n"

#define MSGTR_SMBInitError "Samba kliens knyvtr nem inicializlhat: %d\n"
#define MSGTR_SMBFileNotFound "Nem nyithat meg a hlzatrl: '%s'\n"
#define MSGTR_SMBNotCompiled "Nincs befordtva az MPlayer - be az SMB tmogats\n"

#define MSGTR_CantOpenDVD "Nem tudom megnyitni a DVD eszkzt: %s\n"
#define MSGTR_DVDwait "A lemez struktrjnak olvassa, krlek vrj...\n"
#define MSGTR_DVDnumTitles "%d sv van a DVD-n.\n"
#define MSGTR_DVDinvalidTitle "Helytelen DVD sv: %d\n"
#define MSGTR_DVDnumChapters "Az adott DVD svban %d fejezet van.\n"
#define MSGTR_DVDinvalidChapter "Helytelen DVD fejezet: %d\n"
#define MSGTR_DVDnumAngles "%d darab kameralls van ezen a DVD svon.\n"
#define MSGTR_DVDinvalidAngle "Helytelen DVD kameralls: %d\n"
#define MSGTR_DVDnoIFO "Nem tudom a(z) %d. DVD svhoz megnyitni az IFO file-t.\n"
#define MSGTR_DVDnoVOBs "Nem tudom megnyitni a svot (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDopenOk "DVD sikeresen megnyitva!\n"

// demuxer.c, demux_*.c:
#define MSGTR_AudioStreamRedefined "Vigyzat! Tbbszrsen definilt Audio-folyam: %d (Hibs file?)\n"
#define MSGTR_VideoStreamRedefined "Vigyzat! Tbbszrsen definilt Video-folyam: %d (Hibs file?)\n"
#define MSGTR_TooManyAudioInBuffer "\nDEMUXER: Tl sok (%d db, %d bjt) audio-csomag a pufferben!\n"
#define MSGTR_TooManyVideoInBuffer "\nDEMUXER: Tl sok (%d db, %d bjt) video-csomag a pufferben!\n"
#define MSGTR_MaybeNI "Taln ez egy nem sszefslt (interleaved) file vagy a codec nem mkdik jl?\n" \
		      "AVI file-oknl prbld meg a non-interleaved md knyszertst a -ni opcival.\n"
#define MSGTR_SwitchToNi "\nRosszul sszefslt (interleaved) file, tvlts -ni mdba!\n"
#define MSGTR_Detected_XXX_FileFormat "Ez egy %s formtum file!\n"
#define MSGTR_DetectedAudiofile "Audio file detektlva!\n"
#define MSGTR_NotSystemStream "Nem MPEG System Stream formtum... (taln Transport Stream?)\n"
#define MSGTR_InvalidMPEGES "Hibs MPEG-ES-folyam? Lpj kapcsolatba a ksztkkel, lehet, hogy hiba!\n"
#define MSGTR_FormatNotRecognized "========= Sajnos ez a fileformtum ismeretlen vagy nem tmogatott ===========\n"\
				  "= Ha ez egy AVI, ASF vagy MPEG file, lpj kapcsolatba a ksztkkel (hiba)! =\n"
#define MSGTR_MissingVideoStream "Nincs kpfolyam!\n"
#define MSGTR_MissingAudioStream "Nincs hangfolyam... -> hang nlkl\n"
#define MSGTR_MissingVideoStreamBug "Nincs kpfolyam?! rj a szerznek, lehet hogy hiba :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: a file nem tartalmazza a krt hang vagy kp folyamot\n"

#define MSGTR_NI_Forced "Knyszertve"
#define MSGTR_NI_Detected "Detektlva"
#define MSGTR_NI_Message "%s NON-INTERLEAVED AVI formtum!\n"

#define MSGTR_UsingNINI "NON-INTERLEAVED hibs AVI formtum hasznlata!\n"
#define MSGTR_CouldntDetFNo "Nem tudom meghatrozni a kpkockk szmt (abszolut tekershez)   \n"
#define MSGTR_CantSeekRawAVI "Nem tudok nyers .AVI-kban tekerni! (index kell, prbld az -idx kapcsolval!)\n"
#define MSGTR_CantSeekFile "Nem tudok ebben a fileban tekerni!  \n"

#define MSGTR_EncryptedVOB "Kdolt VOB file (libcss tmogats nincs befordtva!) Olvasd el a doksit\n"
#define MSGTR_EncryptedVOBauth "Kdolt folyam, de nem krtl autentiklst!!\n"

#define MSGTR_MOVcomprhdr "MOV: Tmrtett fejlcek (mg) nincsenek tmogatva!\n"
#define MSGTR_MOVvariableFourCC "MOV: Vigyzat! vltoz FOURCC detektlva!?\n"
#define MSGTR_MOVtooManyTrk "MOV: Vigyzat! tl sok sv!"
#define MSGTR_FoundAudioStream "==> Megtallt audio stream: %d\n"
#define MSGTR_FoundVideoStream "==> Megtallt video stream: %d\n"
#define MSGTR_DetectedTV "TV detektlva! ;-)\n"
#define MSGTR_ErrorOpeningOGGDemuxer "OGG demuxer meghvsa nem sikerlt\n"
#define MSGTR_ASFSearchingForAudioStream "ASF: Audio stream keresse (id:%d)\n"
#define MSGTR_CannotOpenAudioStream "Audio stream megnyitsa sikertelen: %s\n"
#define MSGTR_CannotOpenSubtitlesStream "Felirat stream megnyitsa sikertelen: %s\n"
#define MSGTR_OpeningAudioDemuxerFailed "Audio demuxer meghvsa sikertelen: %s\n"
#define MSGTR_OpeningSubtitlesDemuxerFailed "Felirat demuxer meghvsa sikertelen: %s\n"
#define MSGTR_TVInputNotSeekable "TV bemenet nem tekerhet! (Meg kne csinlni hogy most vltson csatornt ;)\n"
#define MSGTR_DemuxerInfoAlreadyPresent "%s demuxer info mr jelen van!\n"
#define MSGTR_ClipInfo "Clip info: \n"

#define MSGTR_LeaveTelecineMode "\ndemux_mpg: Progresszv file, kilps a 3:2 TELECINE mdbl\n"
#define MSGTR_EnterTelecineMode "\ndemux_mpg: 3:2 TELECINE detektlva, inverz telecine fix hasznlata. Az j FPS: %5.3f!  \n"

// dec_video.c & dec_audio.c:
#define MSGTR_CantOpenCodec "Nem tudom megnyitni a kodeket\n"
#define MSGTR_CantCloseCodec "Nem tudom lezrni a kodeket\n"

#define MSGTR_MissingDLLcodec "HIBA: Nem tudom megnyitni a krt DirectShow kodeket: %s\n"
#define MSGTR_ACMiniterror "Nem tudom betlteni/inicializlni a Win32/ACM kodeket (hinyz DLL file?)\n"
#define MSGTR_MissingLAVCcodec "Nem tallom a(z) '%s' nev kodeket a libavcodec-ben...\n"

#define MSGTR_MpegNoSequHdr "MPEG: VGZETES: vge lett a filenak mikzben a szekvencia fejlcet kerestem\n"
#define MSGTR_CannotReadMpegSequHdr "VGZETES: Nem tudom olvasni a szekvencia fejlcet!\n"
#define MSGTR_CannotReadMpegSequHdrEx "VGZETES: Nem tudom olvasni a szekvencia fejlc kiterjesztst!\n"
#define MSGTR_BadMpegSequHdr "MPEG: Hibs szekvencia fejlc!\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: Hibs szekvencia fejlc kiterjeszts!\n"

#define MSGTR_ShMemAllocFail "Nem tudok megosztott memrit lefoglalni\n"
#define MSGTR_CantAllocAudioBuf "Nem tudok kimeneti hangbuffer lefoglalni\n"

#define MSGTR_UnknownAudio "Ismeretlen/hinyz hangformtum, hang kikapcsolva\n"

#define MSGTR_UsingExternalPP "[PP] Kls minsgjavt filter hasznlata, max minsg = %d\n"
#define MSGTR_UsingCodecPP "[PP] Codecbeli minsgjavts hasznlata, max minsg = %d\n"
#define MSGTR_VideoAttributeNotSupportedByVO_VD "'%s' video tulajdonsg nem tmogatott a kivlasztott vo & vd meghajtk ltal! \n"
#define MSGTR_VideoCodecFamilyNotAvailableStr "A krt [%s] video codec csald (vfm=%s) nem kivlaszthat (fordtsnl kapcsold be!)\n"
#define MSGTR_AudioCodecFamilyNotAvailableStr "A krt [%s] audio codec csald (afm=%s) nem kivlaszthat (fordtsnl kapcsold be!)\n"
#define MSGTR_OpeningVideoDecoder "Video dekder meghvsa: [%s] %s\n"
#define MSGTR_OpeningAudioDecoder "Audio dekder meghvsa: [%s] %s\n"
#define MSGTR_UninitVideoStr "uninit video: %s  \n"
#define MSGTR_UninitAudioStr "uninit audio: %s  \n"
#define MSGTR_VDecoderInitFailed "VDecoder init nem sikerlt :(\n"
#define MSGTR_ADecoderInitFailed "ADecoder init nem sikerlt :(\n"
#define MSGTR_ADecoderPreinitFailed "ADecoder preinit nem sikerlt :(\n"
#define MSGTR_AllocatingBytesForInputBuffer "dec_audio: %d byte alloklsa bemeneti buffernek\n"
#define MSGTR_AllocatingBytesForOutputBuffer "dec_audio: %d + %d = %d byte alloklsa bemeneti buffernek\n"

// LIRC:
#define MSGTR_SettingUpLIRC "lirc tmogats indtsa...\n"
#define MSGTR_LIRCdisabled "Nem fogod tudni hasznlni a tvirnytt\n"
#define MSGTR_LIRCopenfailed "Nem tudtam megnyitni a lirc tmogatst!\n"
#define MSGTR_LIRCcfgerr "Nem tudom olvasni a LIRC konfigurcis file-t : %s \n"

// vf.c
#define MSGTR_CouldNotFindVideoFilter "Nem tallhat a kvetkez video filter '%s'\n"
#define MSGTR_CouldNotOpenVideoFilter "A kvetkez video filter megnyitsa nem sikerlt: '%s'\n"
#define MSGTR_OpeningVideoFilter "Video filter megnyitsa: "
#define MSGTR_CannotFindColorspace "Nem tallhat kzs colorspace, mg a 'scale' filterrel sem :(\n"

// vd.c
#define MSGTR_CodecDidNotSet "VDec: a codec nem lltotta be az sh->disp_w s az sh_disp_h izket, megprblom workaroundolni!\n"
#define MSGTR_VoConfigRequest "VDec: vo config krs - %d x %d (preferlt csp: %s)\n"
#define MSGTR_CouldNotFindColorspace "Nem tallok egyez colorspace-t - jra prblom a -vop scale filterrel...\n"
#define MSGTR_MovieAspectIsSet "A film aspect rtke %.2f:1 - aspect arny javtsa.\n"
#define MSGTR_MovieAspectUndefined "A film aspect rtke nem definilt - nincs arnyjavts.\n"

//  ====================== GUI messages/buttons ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About "Az MPlayer - rl"
#define MSGTR_FileSelect "File kivlasztsa ..."
#define MSGTR_SubtitleSelect "Felirat kivlasztsa ..."
#define MSGTR_OtherSelect "File kivlasztsa ..."
#define MSGTR_AudioFileSelect "Kls audio csatorna vlasztsa ..."
#define MSGTR_FontSelect "Bettipus kivlasztsa ..."
#define MSGTR_PlayList "Lejtszsi lista"
#define MSGTR_Equalizer "Equalizer"
#define MSGTR_SkinBrowser "Skin bngsz"
#define MSGTR_Network "Lejtszs WEB - rl ..."
#define MSGTR_Preferences "Belltsok"
#define MSGTR_OSSPreferences "OSS meghajt belltsok"
#define MSGTR_SDLPreferences "SDL meghajt belltsok"
#define MSGTR_NoMediaOpened "nincs megnyitva semmi"
#define MSGTR_VCDTrack "%d. VCD track"
#define MSGTR_NoChapter "nincs megnyitott fejezet"
#define MSGTR_Chapter "%d. fejezet"
#define MSGTR_NoFileLoaded "nincs file betltve"

// --- buttons ---
#define MSGTR_Ok "Ok"
#define MSGTR_Cancel "Mgse"
#define MSGTR_Add "Hozzad"
#define MSGTR_Remove "Kivesz"
#define MSGTR_Clear "Trls"
#define MSGTR_Config "Bellts"
#define MSGTR_ConfigDriver "Driver belltsa"
#define MSGTR_Browse "Tallzs"

// --- error messages ---
#define MSGTR_NEMDB "Nincs elg memria a buffer kirajzolshoz."
#define MSGTR_NEMFMR "Nincs elg memria a men renderelshez."
#define MSGTR_IDFGCVD "Nem talaltam gui kompatibilis video meghajtt."
#define MSGTR_NEEDLAVCFAME "Nem MPEG file lejtszsa nem lehetsges a DXR3/H+ hardverrel jrakdols nlkl.\nKapcsold be a lavc vagy fame opcit a DXR3/H+ konfigurcis panelen."

// --- skin loader error messages
#define MSGTR_SKIN_ERRORMESSAGE "[skin] hiba a skin konfigurcis file-jnak %d. sorban: %s"
#define MSGTR_SKIN_WARNING1 "[skin] figyelmeztets a skin konfigurcis file-jnak %d. sorban: widget megvan, de nincs eltte \"section\" ( %s )"
#define MSGTR_SKIN_WARNING2 "[skin] figyelmeztets a skin konfigurcis file-jnak %d. sorban: widget megvan, de nincs eltte \"subsection\" ( %s )"
#define MSGTR_SKIN_WARNING3 "[skin] figyelmeztets a skin konfigurcis file-jnak %d. sorban: ez az elem nem hasznlhat ebben az alrszben ( %s )"
#define MSGTR_SKIN_BITMAP_16bit  "16 vagy kevesebb bites bitmap nem tmogatott ( %s ).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound  "file nem tallhat ( %s )\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "bmp olvassi hiba ( %s )\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "tga olvassi hiba ( %s )\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "png olvassi hiba ( %s )\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "RLE tmrtett tga-k nincsenek tmogatva ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "ismeretlen tipus file ( %s )\n"
#define MSGTR_SKIN_BITMAP_ConvertError "hiba a 24-rl 32bitre konvertls kzben ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "ismeretlen zenet: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "nincs elg memria\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "tl sok bettipus van deklarlva\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "nem tallom a bettipus file-t\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "nem tallom a bettipus kpfile-t"
#define MSGTR_SKIN_FONT_NonExistentFontID "nemltez bettipus azonost ( %s )\n"
#define MSGTR_SKIN_UnknownParameter "ismeretlen paramter ( %s )\n"
#define MSGTR_SKINBROWSER_NotEnoughMemory "[skinbngsz] nincs elg memria.\n"
#define MSGTR_SKIN_SKINCFG_SkinNotFound "Skin nem tallhat ( %s ).\n"
#define MSGTR_SKIN_SKINCFG_SkinCfgReadError "Skin configfile olvassi hiba ( %s ).\n"
#define MSGTR_SKIN_LABEL "Skin-ek:"

// --- gtk menus
#define MSGTR_MENU_AboutMPlayer "Az MPlayer-rl"
#define MSGTR_MENU_Open "Megnyits ..."
#define MSGTR_MENU_PlayFile "File lejtszs ..."
#define MSGTR_MENU_PlayVCD "VCD lejtszs ..."  
#define MSGTR_MENU_PlayDVD "DVD lejtszs ..."  
#define MSGTR_MENU_PlayURL "URL lejtszs ..."  
#define MSGTR_MENU_LoadSubtitle "Felirat betltse ..."
#define MSGTR_MENU_DropSubtitle "Felirat eldobsa ..."
#define MSGTR_MENU_LoadExternAudioFile "Kls hang betltse ..."
#define MSGTR_MENU_Playing "Lejtszs"
#define MSGTR_MENU_Play "Lejtszs"
#define MSGTR_MENU_Pause "Pillanatllj"
#define MSGTR_MENU_Stop "llj"  
#define MSGTR_MENU_NextStream "Kvetkez file"
#define MSGTR_MENU_PrevStream "Elz file"
#define MSGTR_MENU_Size "Mret"
#define MSGTR_MENU_NormalSize "Norml mret"
#define MSGTR_MENU_DoubleSize "Dupla mret"
#define MSGTR_MENU_FullScreen "Teljeskperny" 
#define MSGTR_MENU_DVD "DVD"
#define MSGTR_MENU_VCD "VCD"
#define MSGTR_MENU_PlayDisc "Lemez megnyitsa ..."
#define MSGTR_MENU_ShowDVDMenu "DVD men"
#define MSGTR_MENU_Titles "Svok"
#define MSGTR_MENU_Title "%2d. sv"
#define MSGTR_MENU_None "(nincs)"
#define MSGTR_MENU_Chapters "Fejezetek"
#define MSGTR_MENU_Chapter "%2d. fejezet"
#define MSGTR_MENU_AudioLanguages "Szinkron nyelvei"
#define MSGTR_MENU_SubtitleLanguages "Feliratok nyelvei"
#define MSGTR_MENU_PlayList "Lejtszsi lista"
#define MSGTR_MENU_SkinBrowser "Skin bngsz"
#define MSGTR_MENU_Preferences "Belltsok" 
#define MSGTR_MENU_Exit "Kilps ..."
#define MSGTR_MENU_Mute "Nma"
#define MSGTR_MENU_Original "Eredeti"
#define MSGTR_MENU_AspectRatio "Kparny"
#define MSGTR_MENU_AudioTrack "Audio track"
#define MSGTR_MENU_Track "%d. sv"
#define MSGTR_MENU_VideoTrack "Video track"

// --- equalizer
#define MSGTR_EQU_Audio "Audio"
#define MSGTR_EQU_Video "Video"
#define MSGTR_EQU_Contrast "Kontraszt: "
#define MSGTR_EQU_Brightness "Fnyer: "
#define MSGTR_EQU_Hue "Szinrnyalat: "
#define MSGTR_EQU_Saturation "Teltettsg: "
#define MSGTR_EQU_Front_Left "Bal Els"
#define MSGTR_EQU_Front_Right "Jobb Els"
#define MSGTR_EQU_Back_Left "Bal Hts"
#define MSGTR_EQU_Back_Right "Jobb Hts"
#define MSGTR_EQU_Center "Kzps"
#define MSGTR_EQU_Bass "Basszus"
#define MSGTR_EQU_All "Mindegyik"
#define MSGTR_EQU_Channel1 "1. Csatorna"
#define MSGTR_EQU_Channel2 "2. Csatorna"
#define MSGTR_EQU_Channel3 "3. Csatorna"
#define MSGTR_EQU_Channel4 "4. Csatorna"
#define MSGTR_EQU_Channel5 "5. Csatorna"
#define MSGTR_EQU_Channel6 "6. Csatorna"

// --- playlist
#define MSGTR_PLAYLIST_Path "Utvonal"
#define MSGTR_PLAYLIST_Selected "Kivlasztott file - ok"
#define MSGTR_PLAYLIST_Files "File - ok"
#define MSGTR_PLAYLIST_DirectoryTree "Knyvtr lista"

// --- preferences
#define MSGTR_PREFERENCES_Audio "Audio"
#define MSGTR_PREFERENCES_Video "Video"
#define MSGTR_PREFERENCES_SubtitleOSD "Felirat & OSD"
#define MSGTR_PREFERENCES_Codecs "Kodekek s demuxerek"
#define MSGTR_PREFERENCES_Misc "Egyb"

#define MSGTR_PREFERENCES_None "Egyik sem"
#define MSGTR_PREFERENCES_AvailableDrivers "Driverek:"
#define MSGTR_PREFERENCES_DoNotPlaySound "Hang nlkl"
#define MSGTR_PREFERENCES_NormalizeSound "Hang normalizlsa"
#define MSGTR_PREFERENCES_EnEqualizer "Audio equalizer"
#define MSGTR_PREFERENCES_ExtraStereo "Extra stereo"
#define MSGTR_PREFERENCES_Coefficient "Egytthat:"
#define MSGTR_PREFERENCES_AudioDelay "Hang ksleltets"
#define MSGTR_PREFERENCES_DoubleBuffer "Dupla bufferels"
#define MSGTR_PREFERENCES_DirectRender "Direct rendering"
#define MSGTR_PREFERENCES_FrameDrop "Kp eldobs"
#define MSGTR_PREFERENCES_HFrameDrop "Erszakos kp eldob"
#define MSGTR_PREFERENCES_Flip "Kp fejjel lefel"
#define MSGTR_PREFERENCES_Panscan "Panscan: "
#define MSGTR_PREFERENCES_OSDTimer "ra es indiktorok"
#define MSGTR_PREFERENCES_OSDProgress "Csak a szzalk jelzk"
#define MSGTR_PREFERENCES_OSDTimerPercentageTotalTime "ra, szzalk s a teljes id"
#define MSGTR_PREFERENCES_Subtitle "Felirat:"
#define MSGTR_PREFERENCES_SUB_Delay "Ksleltets: "
#define MSGTR_PREFERENCES_SUB_FPS "FPS:"
#define MSGTR_PREFERENCES_SUB_POS "Pozcija: "
#define MSGTR_PREFERENCES_SUB_AutoLoad "Felirat automatikus betltsnek tiltsa"
#define MSGTR_PREFERENCES_SUB_Unicode "Unicode felirat"
#define MSGTR_PREFERENCES_SUB_MPSUB "A film feliratnak konvertlsa MPlayer felirat formtumba"
#define MSGTR_PREFERENCES_SUB_SRT "A film feliratnak konvertlsa SubViewer ( SRT ) formtumba"
#define MSGTR_PREFERENCES_SUB_Overlap "Felirat tlapols"
#define MSGTR_PREFERENCES_Font "Betk:"
#define MSGTR_PREFERENCES_FontFactor "Bet egytthat:"
#define MSGTR_PREFERENCES_PostProcess "Kpjavts"
#define MSGTR_PREFERENCES_AutoQuality "Autmatikus minsg llts: "
#define MSGTR_PREFERENCES_NI "non-interleaved  AVI  felttelezse (hibs AVI-knl segthet"
#define MSGTR_PREFERENCES_IDX "Az AVI indexnek jraptse, ha szksges"
#define MSGTR_PREFERENCES_VideoCodecFamily "Video kodek csald:"
#define MSGTR_PREFERENCES_AudioCodecFamily "Audio kodek csald:"
#define MSGTR_PREFERENCES_FRAME_OSD_Level "OSD szint"
#define MSGTR_PREFERENCES_FRAME_Subtitle "Felirat"
#define MSGTR_PREFERENCES_FRAME_Font "Bet"
#define MSGTR_PREFERENCES_FRAME_PostProcess "Kpjavts"
#define MSGTR_PREFERENCES_FRAME_CodecDemuxer "Codec & demuxer"
#define MSGTR_PREFERENCES_FRAME_Cache "Gyorsttr"
#define MSGTR_PREFERENCES_FRAME_Misc "Egyb"
#define MSGTR_PREFERENCES_OSS_Device "Meghajt:"
#define MSGTR_PREFERENCES_OSS_Mixer "Mixer:"
#define MSGTR_PREFERENCES_SDL_Driver "Meghajt:"
#define MSGTR_PREFERENCES_Message "Krlek emlkezz, nhny opci ignyli a lejtszs jraindtst."
#define MSGTR_PREFERENCES_DXR3_VENC "Video kdol:"
#define MSGTR_PREFERENCES_DXR3_LAVC "LAVC hasznlata (ffmpeg)"
#define MSGTR_PREFERENCES_DXR3_FAME "FAME hasznlata"
#define MSGTR_PREFERENCES_FontEncoding1 "Unicode"
#define MSGTR_PREFERENCES_FontEncoding2 "Nyugat-Eurpai karakterkszlet (ISO-8859-1)"
#define MSGTR_PREFERENCES_FontEncoding3 "Nyugat-Eurpai karakterkszlet eurval (ISO-8859-15)"
#define MSGTR_PREFERENCES_FontEncoding4 "Szlv / Kzp-Eurpai karakterkszlet (ISO-8859-2)"
#define MSGTR_PREFERENCES_FontEncoding5 "Eszperant, gall, mltai, trk karakterkszlet (ISO-8859-3)"
#define MSGTR_PREFERENCES_FontEncoding6 "Rgi baltik karakterkszlet (ISO-8859-4)"
#define MSGTR_PREFERENCES_FontEncoding7 "Cirill karakterkszlet (ISO-8859-5)"
#define MSGTR_PREFERENCES_FontEncoding8 "Arab karakterkszlet (ISO-8859-6)"
#define MSGTR_PREFERENCES_FontEncoding9 "Modern grg karakterkszlet (ISO-8859-7)"
#define MSGTR_PREFERENCES_FontEncoding10 "Trk karakterkszlet (ISO-8859-9)"
#define MSGTR_PREFERENCES_FontEncoding11 "Baltik karakterkszlet (ISO-8859-13"
#define MSGTR_PREFERENCES_FontEncoding12 "Kelta karakterkszlet (ISO-8859-14)"
#define MSGTR_PREFERENCES_FontEncoding13 "Hber karakterkszlet (ISO-8859-8)"
#define MSGTR_PREFERENCES_FontEncoding14 "Orosz karakterkszlet (KOI8-R)"
#define MSGTR_PREFERENCES_FontEncoding15 "Ukrn, Belorusz karakterkszlet (KOI8-U/UR)"
#define MSGTR_PREFERENCES_FontEncoding16 "Egyszer knai karakterkszlet (CP936)"
#define MSGTR_PREFERENCES_FontEncoding17 "Tradicionlis knai karakterkszlet (BIG5)"
#define MSGTR_PREFERENCES_FontEncoding18 "Japn karakterkszlet (SHIFT-JIS)"
#define MSGTR_PREFERENCES_FontEncoding19 "Koreai karakterkszlet (CP949)"
#define MSGTR_PREFERENCES_FontEncoding20 "Thai karakterkszlet (CP874)"
#define MSGTR_PREFERENCES_FontEncoding21 "Cirill Winnyz (CP1251)"
#define MSGTR_PREFERENCES_FontNoAutoScale "Nincs automata karaktermret vlaszts"
#define MSGTR_PREFERENCES_FontPropWidth "Karaktermret film szlessghez val lltsa"
#define MSGTR_PREFERENCES_FontPropHeight "Karaktermret film magassghoz val lltsa"
#define MSGTR_PREFERENCES_FontPropDiagonal "Karaktermret film tljhoz val lltsa"
#define MSGTR_PREFERENCES_FontEncoding "Kdols:"
#define MSGTR_PREFERENCES_FontBlur "Blur:"
#define MSGTR_PREFERENCES_FontOutLine "Krvonal:"
#define MSGTR_PREFERENCES_FontTextScale "Szveg skla:"
#define MSGTR_PREFERENCES_FontOSDScale "OSD skla:"
#define MSGTR_PREFERENCES_Cache "Gyorsttr be/ki"
#define MSGTR_PREFERENCES_CacheSize "Gyorsttr merete:"
#define MSGTR_PREFERENCES_LoadFullscreen "Indts teljes kpernyn"
#define MSGTR_PREFERENCES_SaveWinPos "Ablakok pozcijnak mentse"
#define MSGTR_PREFERENCES_XSCREENSAVER "XScreenSaver lelltsa film lejtszsakor"
#define MSGTR_PREFERENCES_PlayBar "PlayBar engedlyezse"
#define MSGTR_PREFERENCES_AutoSync "AutoSync ki/be kapcsolsa"
#define MSGTR_PREFERENCES_AutoSyncValue "rtke:"
#define MSGTR_PREFERENCES_CDROMDevice "CD meghajt:"
#define MSGTR_PREFERENCES_DVDDevice "DVD meghajt:"
#define MSGTR_PREFERENCES_FPS "Film FPS:"
#define MSGTR_PREFERENCES_ShowVideoWindow "Lejtsz ablak megjelentse ha inaktv"

#define MSGTR_ABOUT_UHU "GUI fejlesztst az UHU Linux tmogatta\n"
#define MSGTR_ABOUT_CoreTeam "   MPlayer csapat:\n"
#define MSGTR_ABOUT_AdditionalCoders "   Tovbbi kderek:\n"
#define MSGTR_ABOUT_MainTesters "   Teszterek:\n"

// --- messagebox
#define MSGTR_MSGBOX_LABEL_FatalError "Vgzetes hiba!"
#define MSGTR_MSGBOX_LABEL_Error "Hiba!"
#define MSGTR_MSGBOX_LABEL_Warning "Figyelmeztets!"

#endif
